// #!/usr/bin/env node

import fs from 'node:fs'
import process from 'node:process'
import colors from 'picocolors'

import pkg from '../../package.json'
import { getRootPath } from '../utils'
import { OUTPUT_DIR } from '../constant'
import { runBuildConfig } from './buildConf'

export async function runBuild() {
    try {
        const argvList = process.argv.splice(2)

        // Generate configuration file
        if (!argvList.includes('disabled-config')) {
            runBuildConfig()
        }

        // 递归删除 dist 目录下的 map 后缀文件
        const dir = getRootPath(OUTPUT_DIR)
        const files = fs.readdirSync(dir)
        files.forEach((file) => {
            if (file.endsWith('.map')) {
                fs.unlinkSync(`${dir}/${file}`)
            }
        })

        console.log(`✨ ${colors.cyan(`[${pkg.name}]`)}` + ' - build successfully!')
    } catch (error) {
        console.log(colors.red(`vite build error:\n${error}`))
        process.exit(1)
    }
}
runBuild()
