import process from 'node:process'
import type { SentryVitePluginOptions } from '@sentry/vite-plugin'
import { sentryVitePlugin } from '@sentry/vite-plugin'
import colors from 'picocolors'
import pkg from '../../../package.json'
import { OUTPUT_DIR } from '../../constant'

export function configSentryPlugin(env: ViteEnv) {
    const config: SentryVitePluginOptions = {
        org: env.VITE_SENTRY_ORG,
        project: env.VITE_SENTRY_PROJECT,
        url: env.VITE_SENTRY_URL,
        authToken: process.env.SENTRY_AUTH_TOKEN,
        release: {
            name: `${pkg.name}@${pkg.version}`,
        },
        sourcemaps: {
            filesToDeleteAfterUpload: [`${OUTPUT_DIR}/**/*.js.map`],
        },
        debug: true,
    }

    console.log(`✨ ${colors.cyan(`[Sentry]`)} config`, config)
    return sentryVitePlugin(config)
}
